"""Task manager configuration constants."""

DEFAULT__APPLICATION__WORKERS = 4
DEFAULT__APPLICATION__TASK_FETCH_INTERVAL = 120
DEFAULT__APPLICATION__DEBUG_MODE = False
DEFAULT__SERVER__HOST = "0.0.0.0"
DEFAULT__SERVER__PORT = 5001
